/* contacts-window.c generated by valac 0.32.0.15-114e9, the Vala compiler
 * generated from contacts-window.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 8 -*- */
/*
 * Copyright (C) 2011 Alexander Larsson <alexl@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <folks/folks-eds.h>
#include <folks/folks.h>
#include <contacts-esd-setup.h>
#include <libedataserver/libedataserver.h>
#include <gee.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>
#include <gdk/gdk.h>
#include <libgd/gd.h>
#include <pango/pango.h>


#define CONTACTS_TYPE_WINDOW (contacts_window_get_type ())
#define CONTACTS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_WINDOW, ContactsWindow))
#define CONTACTS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_WINDOW, ContactsWindowClass))
#define CONTACTS_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_WINDOW))
#define CONTACTS_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_WINDOW))
#define CONTACTS_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_WINDOW, ContactsWindowClass))

typedef struct _ContactsWindow ContactsWindow;
typedef struct _ContactsWindowClass ContactsWindowClass;
typedef struct _ContactsWindowPrivate ContactsWindowPrivate;

#define CONTACTS_TYPE_CONTACT_PANE (contacts_contact_pane_get_type ())
#define CONTACTS_CONTACT_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_CONTACT_PANE, ContactsContactPane))
#define CONTACTS_CONTACT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_CONTACT_PANE, ContactsContactPaneClass))
#define CONTACTS_IS_CONTACT_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_CONTACT_PANE))
#define CONTACTS_IS_CONTACT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_CONTACT_PANE))
#define CONTACTS_CONTACT_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_CONTACT_PANE, ContactsContactPaneClass))

typedef struct _ContactsContactPane ContactsContactPane;
typedef struct _ContactsContactPaneClass ContactsContactPaneClass;

#define CONTACTS_TYPE_ACCOUNTS_LIST (contacts_accounts_list_get_type ())
#define CONTACTS_ACCOUNTS_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_ACCOUNTS_LIST, ContactsAccountsList))
#define CONTACTS_ACCOUNTS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_ACCOUNTS_LIST, ContactsAccountsListClass))
#define CONTACTS_IS_ACCOUNTS_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_ACCOUNTS_LIST))
#define CONTACTS_IS_ACCOUNTS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_ACCOUNTS_LIST))
#define CONTACTS_ACCOUNTS_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_ACCOUNTS_LIST, ContactsAccountsListClass))

typedef struct _ContactsAccountsList ContactsAccountsList;
typedef struct _ContactsAccountsListClass ContactsAccountsListClass;

#define CONTACTS_TYPE_LIST_PANE (contacts_list_pane_get_type ())
#define CONTACTS_LIST_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_LIST_PANE, ContactsListPane))
#define CONTACTS_LIST_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_LIST_PANE, ContactsListPaneClass))
#define CONTACTS_IS_LIST_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_LIST_PANE))
#define CONTACTS_IS_LIST_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_LIST_PANE))
#define CONTACTS_LIST_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_LIST_PANE, ContactsListPaneClass))

typedef struct _ContactsListPane ContactsListPane;
typedef struct _ContactsListPaneClass ContactsListPaneClass;

#define CONTACTS_TYPE_STORE (contacts_store_get_type ())
#define CONTACTS_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_STORE, ContactsStore))
#define CONTACTS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_STORE, ContactsStoreClass))
#define CONTACTS_IS_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_STORE))
#define CONTACTS_IS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_STORE))
#define CONTACTS_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_STORE, ContactsStoreClass))

typedef struct _ContactsStore ContactsStore;
typedef struct _ContactsStoreClass ContactsStoreClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block41Data Block41Data;

#define CONTACTS_TYPE_APP (contacts_app_get_type ())
#define CONTACTS_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_APP, ContactsApp))
#define CONTACTS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_APP, ContactsAppClass))
#define CONTACTS_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_APP))
#define CONTACTS_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_APP))
#define CONTACTS_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_APP, ContactsAppClass))

typedef struct _ContactsApp ContactsApp;
typedef struct _ContactsAppClass ContactsAppClass;
typedef struct _ContactsAppPrivate ContactsAppPrivate;
typedef struct _Block42Data Block42Data;
typedef struct _ContactsAccountsListPrivate ContactsAccountsListPrivate;

#define CONTACTS_TYPE_CONTACT (contacts_contact_get_type ())
#define CONTACTS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_CONTACT, ContactsContact))
#define CONTACTS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_CONTACT, ContactsContactClass))
#define CONTACTS_IS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_CONTACT))
#define CONTACTS_IS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_CONTACT))
#define CONTACTS_CONTACT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_CONTACT, ContactsContactClass))

typedef struct _ContactsContact ContactsContact;
typedef struct _ContactsContactClass ContactsContactClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _ContactsContactPanePrivate ContactsContactPanePrivate;
typedef struct _ContactsListPanePrivate ContactsListPanePrivate;

#define CONTACTS_TYPE_LINK_OPERATION2 (contacts_link_operation2_get_type ())
#define CONTACTS_LINK_OPERATION2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_LINK_OPERATION2, ContactsLinkOperation2))
#define CONTACTS_LINK_OPERATION2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_LINK_OPERATION2, ContactsLinkOperation2Class))
#define CONTACTS_IS_LINK_OPERATION2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_LINK_OPERATION2))
#define CONTACTS_IS_LINK_OPERATION2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_LINK_OPERATION2))
#define CONTACTS_LINK_OPERATION2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_LINK_OPERATION2, ContactsLinkOperation2Class))

typedef struct _ContactsLinkOperation2 ContactsLinkOperation2;
typedef struct _ContactsLinkOperation2Class ContactsLinkOperation2Class;
typedef struct _Block43Data Block43Data;
typedef struct _Block44Data Block44Data;
typedef struct _Block45Data Block45Data;

#define CONTACTS_TYPE_LINK_OPERATION (contacts_link_operation_get_type ())
#define CONTACTS_LINK_OPERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_LINK_OPERATION, ContactsLinkOperation))
#define CONTACTS_LINK_OPERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_LINK_OPERATION, ContactsLinkOperationClass))
#define CONTACTS_IS_LINK_OPERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_LINK_OPERATION))
#define CONTACTS_IS_LINK_OPERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_LINK_OPERATION))
#define CONTACTS_LINK_OPERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_LINK_OPERATION, ContactsLinkOperationClass))

typedef struct _ContactsLinkOperation ContactsLinkOperation;
typedef struct _ContactsLinkOperationClass ContactsLinkOperationClass;
typedef struct _Block46Data Block46Data;

struct _ContactsWindow {
	GtkApplicationWindow parent_instance;
	ContactsWindowPrivate * priv;
};

struct _ContactsWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _ContactsWindowPrivate {
	GtkGrid* content_grid;
	GtkGrid* loading_box;
	GtkSizeGroup* left_pane_size_group;
	GtkHeaderBar* left_toolbar;
	GtkHeaderBar* right_toolbar;
	GtkOverlay* overlay;
	ContactsContactPane* contact_pane;
	GtkButton* add_button;
	GtkToggleButton* select_button;
	GtkButton* edit_button;
	GtkButton* cancel_button;
	GtkButton* done_button;
	GtkStack* view_switcher;
	GtkGrid* content_header_bar;
	GtkHeaderBar* setup_header_bar;
	GtkButton* setup_done_button;
	GtkButton* setup_cancel_button;
	ContactsAccountsList* setup_accounts_list;
	ContactsListPane* list_pane;
	gboolean new_contact_mode;
	ContactsStore* _store;
	gboolean _selection_mode;
	gboolean _edit_mode;
};

struct _Block41Data {
	int _ref_count_;
	ContactsWindow* self;
	GtkApplication* app;
};

struct _ContactsApp {
	GtkApplication parent_instance;
	ContactsAppPrivate * priv;
	GSettings* settings;
	ContactsStore* contacts_store;
	ContactsWindow* window;
};

struct _ContactsAppClass {
	GtkApplicationClass parent_class;
};

struct _Block42Data {
	int _ref_count_;
	Block41Data * _data41_;
	GSimpleAction* change_book_action;
	gulong id2;
};

struct _ContactsAccountsList {
	GtkGrid parent_instance;
	ContactsAccountsListPrivate * priv;
	FolksPersonaStore* selected_store;
};

struct _ContactsAccountsListClass {
	GtkGridClass parent_class;
};

struct _ContactsContactPane {
	GtkNotebook parent_instance;
	ContactsContactPanePrivate * priv;
	ContactsContact* contact;
	gboolean on_edit_mode;
	GtkGrid* suggestion_grid;
};

struct _ContactsContactPaneClass {
	GtkNotebookClass parent_class;
};

struct _ContactsListPane {
	GtkFrame parent_instance;
	ContactsListPanePrivate * priv;
	GtkToolItem* search_tool_item;
	GtkSearchEntry* filter_entry;
	GtkButton* link_button;
	GtkButton* delete_button;
	GtkActionBar* actions_bar;
};

struct _ContactsListPaneClass {
	GtkFrameClass parent_class;
};

struct _Block43Data {
	int _ref_count_;
	ContactsWindow* self;
	ContactsLinkOperation2* operation;
	GdNotification* notification;
};

struct _Block44Data {
	int _ref_count_;
	ContactsWindow* self;
	GdNotification* notification;
	gboolean really_delete;
	GeeLinkedList* contact_list;
};

struct _Block45Data {
	int _ref_count_;
	ContactsWindow* self;
	GdNotification* notification;
	gboolean really_delete;
	ContactsContact* contact;
};

struct _Block46Data {
	int _ref_count_;
	ContactsWindow* self;
	GdNotification* notification;
	ContactsLinkOperation* operation;
};


static gpointer contacts_window_parent_class = NULL;

GType contacts_window_get_type (void) G_GNUC_CONST;
GType contacts_contact_pane_get_type (void) G_GNUC_CONST;
GType contacts_accounts_list_get_type (void) G_GNUC_CONST;
GType contacts_list_pane_get_type (void) G_GNUC_CONST;
GType contacts_store_get_type (void) G_GNUC_CONST;
#define CONTACTS_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CONTACTS_TYPE_WINDOW, ContactsWindowPrivate))
enum  {
	CONTACTS_WINDOW_DUMMY_PROPERTY,
	CONTACTS_WINDOW_STORE,
	CONTACTS_WINDOW_SELECTION_MODE,
	CONTACTS_WINDOW_EDIT_MODE
};
ContactsWindow* contacts_window_new (GtkApplication* app, ContactsStore* contacts_store);
ContactsWindow* contacts_window_construct (GType object_type, GtkApplication* app, ContactsStore* contacts_store);
static Block41Data* block41_data_ref (Block41Data* _data41_);
static void block41_data_unref (void * _userdata_);
void contacts_contact_pane_set_store (ContactsContactPane* self, ContactsStore* value);
GType contacts_app_get_type (void) G_GNUC_CONST;
static Block42Data* block42_data_ref (Block42Data* _data42_);
static void block42_data_unref (void * _userdata_);
ContactsStore* contacts_window_get_store (ContactsWindow* self);
static void ___lambda98_ (ContactsWindow* self);
void contacts_accounts_list_update_contents (ContactsAccountsList* self, gboolean select_active);
static void ____lambda98__contacts_store_eds_persona_store_changed (ContactsStore* _sender, gpointer self);
static void ___lambda99_ (Block42Data* _data42_);
static void ____lambda99__contacts_accounts_list_account_selected (ContactsAccountsList* _sender, gpointer self);
static void ___lambda100_ (Block42Data* _data42_);
static void ____lambda100__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void ___lambda101_ (Block42Data* _data42_);
static void ____lambda101__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void contacts_window_init_content_widgets (ContactsWindow* self);
void contacts_window_set_list_pane (ContactsWindow* self);
ContactsListPane* contacts_list_pane_new (ContactsStore* contacts_store);
ContactsListPane* contacts_list_pane_construct (GType object_type, ContactsStore* contacts_store);
GType contacts_contact_get_type (void) G_GNUC_CONST;
static void contacts_window_list_pane_selection_changed_cb (ContactsWindow* self, ContactsContact* new_selection);
static void _contacts_window_list_pane_selection_changed_cb_contacts_list_pane_selection_changed (ContactsListPane* _sender, ContactsContact* contact, gpointer self);
static void contacts_window_list_pane_link_contacts_cb (ContactsWindow* self, GeeLinkedList* contact_list);
static void _contacts_window_list_pane_link_contacts_cb_contacts_list_pane_link_contacts (ContactsListPane* _sender, GeeLinkedList* contacts_list, gpointer self);
static void contacts_window_list_pane_delete_contacts_cb (ContactsWindow* self, GeeLinkedList* contact_list);
static void _contacts_window_list_pane_delete_contacts_cb_contacts_list_pane_delete_contacts (ContactsListPane* _sender, GeeLinkedList* contacts_list, gpointer self);
static void __lambda110_ (ContactsWindow* self, gint nr_contacts);
static void contacts_window_set_left_title (ContactsWindow* self, const gchar* value);
static void ___lambda110__contacts_list_pane_contacts_marked (ContactsListPane* _sender, gint contacts_marked, gpointer self);
void contacts_list_pane_select_contact (ContactsListPane* self, ContactsContact* contact, gboolean ignore_change);
void contacts_window_activate_selection_mode (ContactsWindow* self, gboolean active);
void contacts_window_set_selection_mode (ContactsWindow* self, gboolean value);
void contacts_list_pane_show_selection (ContactsListPane* self);
void contacts_list_pane_hide_selection (ContactsListPane* self);
void contacts_window_enter_edit_mode (ContactsWindow* self);
void contacts_window_set_edit_mode (ContactsWindow* self, gboolean value);
const gchar* contacts_contact_get_display_name (ContactsContact* self);
static void contacts_window_set_right_title (ContactsWindow* self, const gchar* value);
void contacts_contact_pane_set_edit_mode (ContactsContactPane* self, gboolean on_edit, gboolean drop_changes);
void contacts_window_leave_edit_mode (ContactsWindow* self, gboolean drop_changes);
void contacts_contact_pane_create_contact (ContactsContactPane* self);
void contacts_window_add_notification (ContactsWindow* self, GtkWidget* notification);
void contacts_window_set_shown_contact (ContactsWindow* self, ContactsContact* c);
void contacts_contact_pane_show_contact (ContactsContactPane* self, ContactsContact* new_contact, gboolean show_matches);
void contacts_window_new_contact (ContactsWindow* self);
void contacts_contact_pane_new_contact (ContactsContactPane* self);
static void _contacts_window_new_contact_gtk_button_clicked (GtkButton* _sender, gpointer self);
void contacts_window_show_search (ContactsWindow* self, const gchar* query);
static void __lambda102_ (ContactsWindow* self);
static void ___lambda102__gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
static void __lambda103_ (ContactsWindow* self);
static void ___lambda103__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda104_ (ContactsWindow* self);
static void ___lambda104__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda105_ (ContactsWindow* self);
static void ___lambda105__gtk_button_clicked (GtkButton* _sender, gpointer self);
static gboolean contacts_window_key_press_event_cb (ContactsWindow* self, GdkEventKey* event);
void contacts_utils_grab_entry_focus_no_select (GtkEntry* entry);
static gboolean _contacts_window_key_press_event_cb_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static gboolean contacts_window_delete_event_cb (ContactsWindow* self, GdkEventAny* event);
static gboolean _contacts_window_delete_event_cb_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
GType contacts_link_operation2_get_type (void) G_GNUC_CONST;
static Block43Data* block43_data_ref (Block43Data* _data43_);
static void block43_data_unref (void * _userdata_);
void contacts_link_contacts_list (GeeLinkedList* contact_list, GAsyncReadyCallback _callback_, gpointer _user_data_);
ContactsLinkOperation2* contacts_link_contacts_list_finish (GAsyncResult* _res_);
static void __lambda106_ (Block43Data* _data43_, GObject* obj, GAsyncResult* _result_);
static void ___lambda106__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda107_ (Block43Data* _data43_);
void contacts_link_operation2_undo (ContactsLinkOperation2* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void contacts_link_operation2_undo_finish (ContactsLinkOperation2* self, GAsyncResult* _res_);
static void ___lambda107__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block44Data* block44_data_ref (Block44Data* _data44_);
static void block44_data_unref (void * _userdata_);
static void __lambda108_ (Block44Data* _data44_);
void contacts_contact_remove_personas (ContactsContact* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void contacts_contact_remove_personas_finish (ContactsContact* self, GAsyncResult* _res_, GError** error);
static void ___lambda108__gd_notification_dismissed (GdNotification* _sender, gpointer self);
static void __lambda109_ (Block44Data* _data44_);
void contacts_contact_show (ContactsContact* self);
static void ___lambda109__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void contacts_window_contact_pane_delete_contact_cb (ContactsWindow* self, ContactsContact* contact);
static Block45Data* block45_data_ref (Block45Data* _data45_);
static void block45_data_unref (void * _userdata_);
static void __lambda111_ (Block45Data* _data45_);
static void ___lambda112_ (Block45Data* _data45_);
static void ____lambda112__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda111__gd_notification_dismissed (GdNotification* _sender, gpointer self);
static void __lambda113_ (Block45Data* _data45_);
static void ___lambda113__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void _contacts_window_contact_pane_delete_contact_cb_contacts_contact_pane_will_delete (ContactsContactPane* _sender, ContactsContact* contact, gpointer self);
GType contacts_link_operation_get_type (void) G_GNUC_CONST;
static void contacts_window_contact_pane_contacts_linked_cb (ContactsWindow* self, const gchar* main_contact, const gchar* linked_contact, ContactsLinkOperation* operation);
static Block46Data* block46_data_ref (Block46Data* _data46_);
static void block46_data_unref (void * _userdata_);
static void __lambda114_ (Block46Data* _data46_);
void contacts_link_operation_undo (ContactsLinkOperation* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void contacts_link_operation_undo_finish (ContactsLinkOperation* self, GAsyncResult* _res_);
static void ___lambda114__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void _contacts_window_contact_pane_contacts_linked_cb_contacts_contact_pane_contacts_linked (ContactsContactPane* _sender, const gchar* main_contact, const gchar* linked_contact, ContactsLinkOperation* operation, gpointer self);
static const gchar* contacts_window_get_left_title (ContactsWindow* self);
static const gchar* contacts_window_get_right_title (ContactsWindow* self);
void contacts_window_set_store (ContactsWindow* self, ContactsStore* value);
gboolean contacts_window_get_selection_mode (ContactsWindow* self);
gboolean contacts_window_get_edit_mode (ContactsWindow* self);
static void contacts_window_finalize (GObject* obj);
static void _vala_contacts_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_contacts_window_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static gpointer _g_object_ref0 (gpointer self) {
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return self ? g_object_ref (self) : NULL;
#line 403 "contacts-window.c"
}


static Block41Data* block41_data_ref (Block41Data* _data41_) {
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_atomic_int_inc (&_data41_->_ref_count_);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return _data41_;
#line 412 "contacts-window.c"
}


static void block41_data_unref (void * _userdata_) {
	Block41Data* _data41_;
	_data41_ = (Block41Data*) _userdata_;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (g_atomic_int_dec_and_test (&_data41_->_ref_count_)) {
#line 421 "contacts-window.c"
		ContactsWindow* self;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		self = _data41_->self;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data41_->app);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (self);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_slice_free (Block41Data, _data41_);
#line 431 "contacts-window.c"
	}
}


static Block42Data* block42_data_ref (Block42Data* _data42_) {
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_atomic_int_inc (&_data42_->_ref_count_);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return _data42_;
#line 441 "contacts-window.c"
}


static void block42_data_unref (void * _userdata_) {
	Block42Data* _data42_;
	_data42_ = (Block42Data*) _userdata_;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (g_atomic_int_dec_and_test (&_data42_->_ref_count_)) {
#line 450 "contacts-window.c"
		ContactsWindow* self;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		self = _data42_->_data41_->self;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data42_->change_book_action);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		block41_data_unref (_data42_->_data41_);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_data42_->_data41_ = NULL;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_slice_free (Block42Data, _data42_);
#line 462 "contacts-window.c"
	}
}


static void ___lambda98_ (ContactsWindow* self) {
	ContactsAccountsList* _tmp0_ = NULL;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->setup_accounts_list;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_accounts_list_update_contents (_tmp0_, FALSE);
#line 473 "contacts-window.c"
}


static void ____lambda98__contacts_store_eds_persona_store_changed (ContactsStore* _sender, gpointer self) {
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	___lambda98_ ((ContactsWindow*) self);
#line 480 "contacts-window.c"
}


static void ___lambda99_ (Block42Data* _data42_) {
	Block41Data* _data41_;
	ContactsWindow* self;
	GtkButton* _tmp0_ = NULL;
	ContactsAccountsList* _tmp1_ = NULL;
	gulong _tmp2_ = 0UL;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data41_ = _data42_->_data41_;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data41_->self;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->setup_done_button;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, TRUE);
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = self->priv->setup_accounts_list;
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = _data42_->id2;
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 504 "contacts-window.c"
}


static void ____lambda99__contacts_accounts_list_account_selected (ContactsAccountsList* _sender, gpointer self) {
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	___lambda99_ (self);
#line 511 "contacts-window.c"
}


static void ___lambda100_ (Block42Data* _data42_) {
	Block41Data* _data41_;
	ContactsWindow* self;
	GtkStack* _tmp0_ = NULL;
	GtkGrid* _tmp1_ = NULL;
	EdsfPersonaStore* e_store = NULL;
	ContactsAccountsList* _tmp2_ = NULL;
	FolksPersonaStore* _tmp3_ = NULL;
	EdsfPersonaStore* _tmp4_ = NULL;
	ESourceRegistry* _tmp5_ = NULL;
	EdsfPersonaStore* _tmp6_ = NULL;
	ESource* _tmp7_ = NULL;
	ESource* _tmp8_ = NULL;
	GtkApplication* _tmp9_ = NULL;
	GSettings* _tmp10_ = NULL;
	GSimpleAction* _tmp11_ = NULL;
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data41_ = _data42_->_data41_;
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data41_->self;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->view_switcher;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_stack_set_visible_child_name (_tmp0_, "content-view");
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = self->priv->content_header_bar;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_window_set_titlebar ((GtkWindow*) self, (GtkWidget*) _tmp1_);
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = self->priv->setup_accounts_list;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = _tmp2_->selected_store;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, EDSF_TYPE_PERSONA_STORE) ? ((EdsfPersonaStore*) _tmp3_) : NULL);
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	e_store = _tmp4_;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = eds_source_registry;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = e_store;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = edsf_persona_store_get_source (_tmp6_);
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp8_ = _tmp7_;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	e_source_registry_set_default_address_book (_tmp5_, _tmp8_);
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp9_ = _data41_->app;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp10_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, CONTACTS_TYPE_APP) ? ((ContactsApp*) _tmp9_) : NULL)->settings;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_settings_set_boolean (_tmp10_, "did-initial-setup", TRUE);
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp11_ = _data42_->change_book_action;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp11_ != NULL) {
#line 571 "contacts-window.c"
		GSimpleAction* _tmp12_ = NULL;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp12_ = _data42_->change_book_action;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_simple_action_set_enabled (_tmp12_, TRUE);
#line 577 "contacts-window.c"
	}
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (e_store);
#line 581 "contacts-window.c"
}


static void ____lambda100__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	___lambda100_ (self);
#line 588 "contacts-window.c"
}


static void ___lambda101_ (Block42Data* _data42_) {
	Block41Data* _data41_;
	ContactsWindow* self;
	GtkApplication* _tmp0_ = NULL;
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data41_ = _data42_->_data41_;
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data41_->self;
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = _data41_->app;
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_application_quit ((GApplication*) _tmp0_);
#line 604 "contacts-window.c"
}


static void ____lambda101__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	___lambda101_ (self);
#line 611 "contacts-window.c"
}


ContactsWindow* contacts_window_construct (GType object_type, GtkApplication* app, ContactsStore* contacts_store) {
	ContactsWindow * self = NULL;
	Block41Data* _data41_;
	GtkApplication* _tmp0_ = NULL;
	GtkApplication* _tmp1_ = NULL;
	GtkApplication* _tmp2_ = NULL;
	ContactsStore* _tmp3_ = NULL;
	ContactsContactPane* _tmp4_ = NULL;
	ContactsStore* _tmp5_ = NULL;
	GtkHeaderBar* _tmp6_ = NULL;
	GtkButton* _tmp7_ = NULL;
	GtkButton* _tmp8_ = NULL;
	GtkButton* _tmp9_ = NULL;
	GtkButton* _tmp10_ = NULL;
	GtkButton* _tmp11_ = NULL;
	GtkButton* _tmp12_ = NULL;
	GtkToggleButton* _tmp13_ = NULL;
	GtkHeaderBar* _tmp14_ = NULL;
	GtkApplication* _tmp15_ = NULL;
	GSettings* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (app != NULL, NULL);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (contacts_store != NULL, NULL);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data41_ = g_slice_new0 (Block41Data);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data41_->_ref_count_ = 1;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = app;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (_data41_->app);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data41_->app = _tmp1_;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = _data41_->app;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = contacts_store;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = (ContactsWindow*) g_object_new (object_type, "application", _tmp2_, "store", _tmp3_, NULL);
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data41_->self = g_object_ref (self);
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_debug ("contacts-window.vala:101: everyone creation: finalized already!!!");
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = self->priv->contact_pane;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = contacts_store;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_contact_pane_set_store (_tmp4_, _tmp5_);
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = self->priv->right_toolbar;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_bind_property_with_closures ((GObject*) self, "selection-mode", (GObject*) _tmp6_, "show-close-button", G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = self->priv->add_button;
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_bind_property_with_closures ((GObject*) self, "selection-mode", (GObject*) _tmp7_, "visible", G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp8_ = self->priv->edit_button;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_bind_property_with_closures ((GObject*) self, "selection-mode", (GObject*) _tmp8_, "visible", G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 119 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp9_ = self->priv->edit_button;
#line 119 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_bind_property_with_closures ((GObject*) self, "edit-mode", (GObject*) _tmp9_, "visible", G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp10_ = self->priv->done_button;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_bind_property_with_closures ((GObject*) self, "edit-mode", (GObject*) _tmp10_, "visible", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp11_ = self->priv->cancel_button;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_bind_property_with_closures ((GObject*) self, "edit-mode", (GObject*) _tmp11_, "visible", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp12_ = self->priv->add_button;
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_bind_property_with_closures ((GObject*) self, "edit-mode", (GObject*) _tmp12_, "visible", G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp13_ = self->priv->select_button;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_bind_property_with_closures ((GObject*) self, "edit-mode", (GObject*) _tmp13_, "visible", G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 137 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp14_ = self->priv->right_toolbar;
#line 137 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_bind_property_with_closures ((GObject*) self, "edit-mode", (GObject*) _tmp14_, "show-close-button", G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp15_ = _data41_->app;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp16_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, CONTACTS_TYPE_APP) ? ((ContactsApp*) _tmp15_) : NULL)->settings;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp17_ = g_settings_get_boolean (_tmp16_, "did-initial-setup");
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp17_) {
#line 712 "contacts-window.c"
		GtkStack* _tmp18_ = NULL;
		GtkGrid* _tmp19_ = NULL;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp18_ = self->priv->view_switcher;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_stack_set_visible_child_name (_tmp18_, "content-view");
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp19_ = self->priv->content_header_bar;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_window_set_titlebar ((GtkWindow*) self, (GtkWidget*) _tmp19_);
#line 723 "contacts-window.c"
	} else {
		Block42Data* _data42_;
		GtkApplication* _tmp20_ = NULL;
		GAction* _tmp21_ = NULL;
		GSimpleAction* _tmp22_ = NULL;
		GSimpleAction* _tmp23_ = NULL;
		ContactsStore* _tmp25_ = NULL;
		ContactsAccountsList* _tmp26_ = NULL;
		gulong _tmp27_ = 0UL;
		GtkStack* _tmp28_ = NULL;
		GtkHeaderBar* _tmp29_ = NULL;
		ContactsAccountsList* _tmp30_ = NULL;
		GtkButton* _tmp31_ = NULL;
		GtkButton* _tmp32_ = NULL;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_data42_ = g_slice_new0 (Block42Data);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_data42_->_ref_count_ = 1;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_data42_->_data41_ = block41_data_ref (_data41_);
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp20_ = _data41_->app;
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp21_ = g_action_map_lookup_action ((GActionMap*) _tmp20_, "change_book");
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp21_) : NULL);
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_data42_->change_book_action = _tmp22_;
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp23_ = _data42_->change_book_action;
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		if (_tmp23_ != NULL) {
#line 756 "contacts-window.c"
			GSimpleAction* _tmp24_ = NULL;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp24_ = _data42_->change_book_action;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			g_simple_action_set_enabled (_tmp24_, FALSE);
#line 762 "contacts-window.c"
		}
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp25_ = self->priv->_store;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_signal_connect_object (_tmp25_, "eds-persona-store-changed", (GCallback) ____lambda98__contacts_store_eds_persona_store_changed, self, 0);
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_data42_->id2 = (gulong) 0;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp26_ = self->priv->setup_accounts_list;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp27_ = g_signal_connect_data (_tmp26_, "account-selected", (GCallback) ____lambda99__contacts_accounts_list_account_selected, block42_data_ref (_data42_), (GClosureNotify) block42_data_unref, 0);
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_data42_->id2 = _tmp27_;
#line 160 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp28_ = self->priv->view_switcher;
#line 160 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_stack_set_visible_child_name (_tmp28_, "setup-view");
#line 161 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp29_ = self->priv->setup_header_bar;
#line 161 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_window_set_titlebar ((GtkWindow*) self, (GtkWidget*) _tmp29_);
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp30_ = self->priv->setup_accounts_list;
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_accounts_list_update_contents (_tmp30_, FALSE);
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp31_ = self->priv->setup_done_button;
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_signal_connect_data (_tmp31_, "clicked", (GCallback) ____lambda100__gtk_button_clicked, block42_data_ref (_data42_), (GClosureNotify) block42_data_unref, 0);
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp32_ = self->priv->setup_cancel_button;
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_signal_connect_data (_tmp32_, "clicked", (GCallback) ____lambda101__gtk_button_clicked, block42_data_ref (_data42_), (GClosureNotify) block42_data_unref, 0);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		block42_data_unref (_data42_);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_data42_ = NULL;
#line 800 "contacts-window.c"
	}
#line 182 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_init_content_widgets (self);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	block41_data_unref (_data41_);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data41_ = NULL;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return self;
#line 810 "contacts-window.c"
}


ContactsWindow* contacts_window_new (GtkApplication* app, ContactsStore* contacts_store) {
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return contacts_window_construct (CONTACTS_TYPE_WINDOW, app, contacts_store);
#line 817 "contacts-window.c"
}


static void _contacts_window_list_pane_selection_changed_cb_contacts_list_pane_selection_changed (ContactsListPane* _sender, ContactsContact* contact, gpointer self) {
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_list_pane_selection_changed_cb ((ContactsWindow*) self, contact);
#line 824 "contacts-window.c"
}


static void _contacts_window_list_pane_link_contacts_cb_contacts_list_pane_link_contacts (ContactsListPane* _sender, GeeLinkedList* contacts_list, gpointer self) {
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_list_pane_link_contacts_cb ((ContactsWindow*) self, contacts_list);
#line 831 "contacts-window.c"
}


static void _contacts_window_list_pane_delete_contacts_cb_contacts_list_pane_delete_contacts (ContactsListPane* _sender, GeeLinkedList* contacts_list, gpointer self) {
#line 194 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_list_pane_delete_contacts_cb ((ContactsWindow*) self, contacts_list);
#line 838 "contacts-window.c"
}


static void __lambda110_ (ContactsWindow* self, gint nr_contacts) {
	gint _tmp0_ = 0;
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = nr_contacts;
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp0_ == 0) {
#line 848 "contacts-window.c"
		const gchar* _tmp1_ = NULL;
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp1_ = _ ("Select");
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_left_title (self, _tmp1_);
#line 854 "contacts-window.c"
	} else {
		gint _tmp2_ = 0;
		const gchar* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp2_ = nr_contacts;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp3_ = ngettext ("%d Selected", "%d Selected", (gulong) _tmp2_);
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp4_ = nr_contacts;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp5_ = g_strdup_printf (_tmp3_, _tmp4_);
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp6_ = _tmp5_;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_left_title (self, _tmp6_);
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_free0 (_tmp6_);
#line 875 "contacts-window.c"
	}
}


static void ___lambda110__contacts_list_pane_contacts_marked (ContactsListPane* _sender, gint contacts_marked, gpointer self) {
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda110_ ((ContactsWindow*) self, contacts_marked);
#line 883 "contacts-window.c"
}


void contacts_window_set_list_pane (ContactsWindow* self) {
	ContactsListPane* _tmp0_ = NULL;
	ContactsStore* _tmp1_ = NULL;
	ContactsListPane* _tmp2_ = NULL;
	ContactsListPane* _tmp3_ = NULL;
	ContactsListPane* _tmp4_ = NULL;
	ContactsListPane* _tmp5_ = NULL;
	ContactsListPane* _tmp6_ = NULL;
	GtkSizeGroup* _tmp7_ = NULL;
	ContactsListPane* _tmp8_ = NULL;
	GtkSizeGroup* _tmp9_ = NULL;
	GtkGrid* _tmp10_ = NULL;
	GtkGrid* _tmp11_ = NULL;
	GtkGrid* _tmp12_ = NULL;
	ContactsListPane* _tmp13_ = NULL;
	ContactsContactPane* _tmp14_ = NULL;
	ContactsContact* _tmp15_ = NULL;
	ContactsListPane* _tmp19_ = NULL;
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->list_pane;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp0_ != NULL) {
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		return;
#line 913 "contacts-window.c"
	}
#line 191 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = self->priv->_store;
#line 191 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = contacts_list_pane_new (_tmp1_);
#line 191 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp2_);
#line 191 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->list_pane);
#line 191 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self->priv->list_pane = _tmp2_;
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = self->priv->list_pane;
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_object (_tmp3_, "selection-changed", (GCallback) _contacts_window_list_pane_selection_changed_cb_contacts_list_pane_selection_changed, self, 0);
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = self->priv->list_pane;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_object (_tmp4_, "link-contacts", (GCallback) _contacts_window_list_pane_link_contacts_cb_contacts_list_pane_link_contacts, self, 0);
#line 194 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = self->priv->list_pane;
#line 194 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_object (_tmp5_, "delete-contacts", (GCallback) _contacts_window_list_pane_delete_contacts_cb_contacts_list_pane_delete_contacts, self, 0);
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = self->priv->list_pane;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_object (_tmp6_, "contacts-marked", (GCallback) ___lambda110__contacts_list_pane_contacts_marked, self, 0);
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = self->priv->left_pane_size_group;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp8_ = self->priv->list_pane;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_size_group_add_widget (_tmp7_, (GtkWidget*) _tmp8_);
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp9_ = self->priv->left_pane_size_group;
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp10_ = self->priv->loading_box;
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_size_group_remove_widget (_tmp9_, (GtkWidget*) _tmp10_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp11_ = self->priv->loading_box;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp11_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp12_ = self->priv->content_grid;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp13_ = self->priv->list_pane;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_grid_attach (_tmp12_, (GtkWidget*) _tmp13_, 0, 0, 1, 1);
#line 211 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp14_ = self->priv->contact_pane;
#line 211 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp15_ = _tmp14_->contact;
#line 211 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp15_ != NULL) {
#line 969 "contacts-window.c"
		ContactsListPane* _tmp16_ = NULL;
		ContactsContactPane* _tmp17_ = NULL;
		ContactsContact* _tmp18_ = NULL;
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp16_ = self->priv->list_pane;
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp17_ = self->priv->contact_pane;
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp18_ = _tmp17_->contact;
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_list_pane_select_contact (_tmp16_, _tmp18_, FALSE);
#line 981 "contacts-window.c"
	}
#line 214 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp19_ = self->priv->list_pane;
#line 214 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_show ((GtkWidget*) _tmp19_);
#line 987 "contacts-window.c"
}


void contacts_window_activate_selection_mode (ContactsWindow* self, gboolean active) {
	gboolean _tmp0_ = FALSE;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = active;
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp0_) {
#line 999 "contacts-window.c"
		GtkHeaderBar* _tmp1_ = NULL;
		GtkStyleContext* _tmp2_ = NULL;
		GtkHeaderBar* _tmp3_ = NULL;
		GtkStyleContext* _tmp4_ = NULL;
		GtkHeaderBar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		ContactsListPane* _tmp7_ = NULL;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_selection_mode (self, TRUE);
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp1_ = self->priv->left_toolbar;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) _tmp1_);
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_style_context_add_class (_tmp2_, "selection-mode");
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp3_ = self->priv->right_toolbar;
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_style_context_add_class (_tmp4_, "selection-mode");
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp5_ = self->priv->left_toolbar;
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp6_ = _ ("Select");
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_header_bar_set_title (_tmp5_, _tmp6_);
#line 226 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp7_ = self->priv->list_pane;
#line 226 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_list_pane_show_selection (_tmp7_);
#line 1031 "contacts-window.c"
	} else {
		GtkHeaderBar* _tmp8_ = NULL;
		GtkStyleContext* _tmp9_ = NULL;
		GtkHeaderBar* _tmp10_ = NULL;
		GtkStyleContext* _tmp11_ = NULL;
		GtkHeaderBar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		ContactsListPane* _tmp14_ = NULL;
		ContactsContactPane* _tmp15_ = NULL;
		ContactsContact* _tmp16_ = NULL;
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_selection_mode (self, FALSE);
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp8_ = self->priv->left_toolbar;
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) _tmp8_);
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_style_context_remove_class (_tmp9_, "selection-mode");
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp10_ = self->priv->right_toolbar;
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp11_ = gtk_widget_get_style_context ((GtkWidget*) _tmp10_);
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_style_context_remove_class (_tmp11_, "selection-mode");
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp12_ = self->priv->left_toolbar;
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp13_ = _ ("All Contacts");
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_header_bar_set_title (_tmp12_, _tmp13_);
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp14_ = self->priv->list_pane;
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_list_pane_hide_selection (_tmp14_);
#line 238 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp15_ = self->priv->contact_pane;
#line 238 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp16_ = _tmp15_->contact;
#line 238 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		if (_tmp16_ == NULL) {
#line 1072 "contacts-window.c"
			GtkButton* _tmp17_ = NULL;
#line 239 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp17_ = self->priv->edit_button;
#line 239 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			gtk_widget_hide ((GtkWidget*) _tmp17_);
#line 1078 "contacts-window.c"
		}
	}
}


void contacts_window_enter_edit_mode (ContactsWindow* self) {
	ContactsContactPane* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
	gchar* name = NULL;
	ContactsContactPane* _tmp2_ = NULL;
	ContactsContact* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	GtkHeaderBar* _tmp11_ = NULL;
	GtkStyleContext* _tmp12_ = NULL;
	GtkHeaderBar* _tmp13_ = NULL;
	GtkStyleContext* _tmp14_ = NULL;
	ContactsContactPane* _tmp15_ = NULL;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->contact_pane;
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _tmp0_->contact;
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp1_ == NULL) {
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		return;
#line 1112 "contacts-window.c"
	}
#line 247 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_edit_mode (self, TRUE);
#line 249 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = self->priv->contact_pane;
#line 249 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = _tmp2_->contact;
#line 249 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = contacts_contact_get_display_name (_tmp3_);
#line 249 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = _tmp4_;
#line 249 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 249 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	name = _tmp6_;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = _ ("Editing %s");
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp8_ = name;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp9_ = g_strdup_printf (_tmp7_, _tmp8_);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp10_ = _tmp9_;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_right_title (self, _tmp10_);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_free0 (_tmp10_);
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp11_ = self->priv->left_toolbar;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp12_ = gtk_widget_get_style_context ((GtkWidget*) _tmp11_);
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_style_context_add_class (_tmp12_, "selection-mode");
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp13_ = self->priv->right_toolbar;
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp14_ = gtk_widget_get_style_context ((GtkWidget*) _tmp13_);
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_style_context_add_class (_tmp14_, "selection-mode");
#line 255 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp15_ = self->priv->contact_pane;
#line 255 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_contact_pane_set_edit_mode (_tmp15_, TRUE, FALSE);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_free0 (name);
#line 1158 "contacts-window.c"
}


void contacts_window_leave_edit_mode (ContactsWindow* self, gboolean drop_changes) {
	GtkHeaderBar* _tmp0_ = NULL;
	GtkStyleContext* _tmp1_ = NULL;
	GtkHeaderBar* _tmp2_ = NULL;
	GtkStyleContext* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	ContactsContactPane* _tmp13_ = NULL;
	ContactsContact* _tmp14_ = NULL;
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 259 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_edit_mode (self, FALSE);
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->left_toolbar;
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) _tmp0_);
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_style_context_remove_class (_tmp1_, "selection-mode");
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = self->priv->right_toolbar;
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = gtk_widget_get_style_context ((GtkWidget*) _tmp2_);
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_style_context_remove_class (_tmp3_, "selection-mode");
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = self->priv->new_contact_mode;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp4_) {
#line 1190 "contacts-window.c"
		GtkButton* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp5_ = self->priv->done_button;
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp6_ = _ ("Done");
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_button_set_label (_tmp5_, _tmp6_);
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp7_ = drop_changes;
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		if (_tmp7_) {
#line 1204 "contacts-window.c"
			ContactsContactPane* _tmp8_ = NULL;
			gboolean _tmp9_ = FALSE;
#line 268 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp8_ = self->priv->contact_pane;
#line 268 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp9_ = drop_changes;
#line 268 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			contacts_contact_pane_set_edit_mode (_tmp8_, FALSE, _tmp9_);
#line 1213 "contacts-window.c"
		} else {
			ContactsContactPane* _tmp10_ = NULL;
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp10_ = self->priv->contact_pane;
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			contacts_contact_pane_create_contact (_tmp10_);
#line 1220 "contacts-window.c"
		}
#line 272 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		self->priv->new_contact_mode = FALSE;
#line 1224 "contacts-window.c"
	} else {
		ContactsContactPane* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp11_ = self->priv->contact_pane;
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp12_ = drop_changes;
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_contact_pane_set_edit_mode (_tmp11_, FALSE, _tmp12_);
#line 1234 "contacts-window.c"
	}
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp13_ = self->priv->contact_pane;
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp14_ = _tmp13_->contact;
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp14_ != NULL) {
#line 1242 "contacts-window.c"
		ContactsContactPane* _tmp15_ = NULL;
		ContactsContact* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp15_ = self->priv->contact_pane;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp16_ = _tmp15_->contact;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp17_ = contacts_contact_get_display_name (_tmp16_);
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp18_ = _tmp17_;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_right_title (self, _tmp18_);
#line 1257 "contacts-window.c"
	} else {
		GtkButton* _tmp19_ = NULL;
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_right_title (self, "");
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp19_ = self->priv->edit_button;
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_widget_hide ((GtkWidget*) _tmp19_);
#line 1266 "contacts-window.c"
	}
}


void contacts_window_add_notification (ContactsWindow* self, GtkWidget* notification) {
	GtkOverlay* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 285 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 285 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (notification != NULL);
#line 286 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->overlay;
#line 286 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = notification;
#line 286 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_overlay_add_overlay (_tmp0_, _tmp1_);
#line 1284 "contacts-window.c"
}


void contacts_window_set_shown_contact (ContactsWindow* self, ContactsContact* c) {
	ContactsContactPane* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	ContactsContactPane* _tmp2_ = NULL;
	ContactsContact* _tmp3_ = NULL;
	ContactsListPane* _tmp4_ = NULL;
	ContactsContact* _tmp7_ = NULL;
	gboolean _tmp11_ = FALSE;
	ContactsContact* _tmp12_ = NULL;
	GtkButton* _tmp16_ = NULL;
#line 289 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 291 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->contact_pane;
#line 291 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _tmp0_->on_edit_mode;
#line 291 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp1_) {
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_leave_edit_mode (self, FALSE);
#line 1308 "contacts-window.c"
	}
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = self->priv->contact_pane;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = c;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_contact_pane_show_contact (_tmp2_, _tmp3_, FALSE);
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = self->priv->list_pane;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp4_ != NULL) {
#line 1320 "contacts-window.c"
		ContactsListPane* _tmp5_ = NULL;
		ContactsContact* _tmp6_ = NULL;
#line 297 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp5_ = self->priv->list_pane;
#line 297 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp6_ = c;
#line 297 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_list_pane_select_contact (_tmp5_, _tmp6_, FALSE);
#line 1329 "contacts-window.c"
	}
#line 300 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = c;
#line 300 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp7_ != NULL) {
#line 1335 "contacts-window.c"
		ContactsContact* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 301 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp8_ = c;
#line 301 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp9_ = contacts_contact_get_display_name (_tmp8_);
#line 301 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp10_ = _tmp9_;
#line 301 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_right_title (self, _tmp10_);
#line 1347 "contacts-window.c"
	} else {
#line 303 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_right_title (self, "");
#line 1351 "contacts-window.c"
	}
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp12_ = c;
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp12_ != NULL) {
#line 1357 "contacts-window.c"
		GtkToggleButton* _tmp13_ = NULL;
		gboolean _tmp14_ = FALSE;
		gboolean _tmp15_ = FALSE;
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp13_ = self->priv->select_button;
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp14_ = gtk_toggle_button_get_active (_tmp13_);
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp15_ = _tmp14_;
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp11_ = !_tmp15_;
#line 1369 "contacts-window.c"
	} else {
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp11_ = FALSE;
#line 1373 "contacts-window.c"
	}
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp16_ = self->priv->edit_button;
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp16_, _tmp11_);
#line 1379 "contacts-window.c"
}


void contacts_window_new_contact (ContactsWindow* self) {
	const gchar* _tmp0_ = NULL;
	GtkHeaderBar* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkHeaderBar* _tmp3_ = NULL;
	GtkStyleContext* _tmp4_ = NULL;
	GtkButton* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	ContactsContactPane* _tmp7_ = NULL;
#line 309 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_edit_mode (self, TRUE);
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self->priv->new_contact_mode = TRUE;
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = _ ("New Contact");
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_right_title (self, _tmp0_);
#line 317 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = self->priv->left_toolbar;
#line 317 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) _tmp1_);
#line 317 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_style_context_add_class (_tmp2_, "selection-mode");
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = self->priv->right_toolbar;
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_style_context_add_class (_tmp4_, "selection-mode");
#line 320 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = self->priv->done_button;
#line 320 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = _ ("Add");
#line 320 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_button_set_label (_tmp5_, _tmp6_);
#line 322 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = self->priv->contact_pane;
#line 322 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_contact_pane_new_contact (_tmp7_);
#line 1424 "contacts-window.c"
}


static void _contacts_window_new_contact_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_new_contact ((ContactsWindow*) self);
#line 1431 "contacts-window.c"
}


void contacts_window_show_search (ContactsWindow* self, const gchar* query) {
	ContactsListPane* _tmp0_ = NULL;
	GtkSearchEntry* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (query != NULL);
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->list_pane;
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _tmp0_->filter_entry;
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = query;
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_entry_set_text ((GtkEntry*) _tmp1_, _tmp2_);
#line 1451 "contacts-window.c"
}


static void __lambda102_ (ContactsWindow* self) {
	GtkToggleButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->select_button;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = gtk_toggle_button_get_active (_tmp0_);
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = _tmp1_;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_activate_selection_mode (self, _tmp2_);
#line 1467 "contacts-window.c"
}


static void ___lambda102__gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda102_ ((ContactsWindow*) self);
#line 1474 "contacts-window.c"
}


static void __lambda103_ (ContactsWindow* self) {
#line 346 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_enter_edit_mode (self);
#line 1481 "contacts-window.c"
}


static void ___lambda103__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 345 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda103_ ((ContactsWindow*) self);
#line 1488 "contacts-window.c"
}


static void __lambda104_ (ContactsWindow* self) {
#line 350 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_leave_edit_mode (self, FALSE);
#line 1495 "contacts-window.c"
}


static void ___lambda104__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 349 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda104_ ((ContactsWindow*) self);
#line 1502 "contacts-window.c"
}


static void __lambda105_ (ContactsWindow* self) {
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_leave_edit_mode (self, TRUE);
#line 1509 "contacts-window.c"
}


static void ___lambda105__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda105_ ((ContactsWindow*) self);
#line 1516 "contacts-window.c"
}


static void contacts_window_init_content_widgets (ContactsWindow* self) {
	gchar* layout_desc = NULL;
	gchar** tokens = NULL;
	gint tokens_length1 = 0;
	gint _tokens_size_ = 0;
	GtkSettings* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gchar** _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
	GtkToggleButton* _tmp15_ = NULL;
	GtkButton* _tmp16_ = NULL;
	GtkButton* _tmp17_ = NULL;
	GtkButton* _tmp18_ = NULL;
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 334 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 334 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_get (_tmp0_, "gtk-decoration-layout", &_tmp1_, NULL);
#line 334 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = _tmp1_;
#line 334 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_free0 (layout_desc);
#line 334 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	layout_desc = _tmp2_;
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = layout_desc;
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = _tmp4_ = g_strsplit (_tmp3_, ":", 2);
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	tokens = _tmp5_;
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	tokens_length1 = _vala_array_length (_tmp4_);
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tokens_size_ = tokens_length1;
#line 336 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = tokens;
#line 336 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6__length1 = tokens_length1;
#line 336 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp6_ != NULL) {
#line 1567 "contacts-window.c"
		GtkHeaderBar* _tmp7_ = NULL;
		gchar** _tmp8_ = NULL;
		gint _tmp8__length1 = 0;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GtkHeaderBar* _tmp12_ = NULL;
		gchar** _tmp13_ = NULL;
		gint _tmp13__length1 = 0;
		const gchar* _tmp14_ = NULL;
#line 337 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp7_ = self->priv->right_toolbar;
#line 337 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp8_ = tokens;
#line 337 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp8__length1 = tokens_length1;
#line 337 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp9_ = _tmp8_[1];
#line 337 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp10_ = g_strdup_printf (":%s", _tmp9_);
#line 337 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp11_ = _tmp10_;
#line 337 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_header_bar_set_decoration_layout (_tmp7_, _tmp11_);
#line 337 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_free0 (_tmp11_);
#line 338 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp12_ = self->priv->left_toolbar;
#line 338 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp13_ = tokens;
#line 338 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp13__length1 = tokens_length1;
#line 338 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp14_ = _tmp13_[0];
#line 338 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_header_bar_set_decoration_layout (_tmp12_, _tmp14_);
#line 1604 "contacts-window.c"
	}
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp15_ = self->priv->select_button;
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_object (_tmp15_, "toggled", (GCallback) ___lambda102__gtk_toggle_button_toggled, self, 0);
#line 345 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp16_ = self->priv->edit_button;
#line 345 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_object (_tmp16_, "clicked", (GCallback) ___lambda103__gtk_button_clicked, self, 0);
#line 349 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp17_ = self->priv->done_button;
#line 349 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_object (_tmp17_, "clicked", (GCallback) ___lambda104__gtk_button_clicked, self, 0);
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp18_ = self->priv->cancel_button;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_object (_tmp18_, "clicked", (GCallback) ___lambda105__gtk_button_clicked, self, 0);
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_free0 (layout_desc);
#line 1626 "contacts-window.c"
}


static gboolean contacts_window_key_press_event_cb (ContactsWindow* self, GdkEventKey* event) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GdkEventKey* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
	guint _tmp3_ = 0U;
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 360 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = event;
#line 360 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = _tmp1_->keyval;
#line 360 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = gdk_keyval_from_name ("q");
#line 360 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp2_ == _tmp3_) {
#line 1648 "contacts-window.c"
		GdkEventKey* _tmp4_ = NULL;
		GdkModifierType _tmp5_ = 0;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp4_ = event;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp5_ = _tmp4_->state;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp0_ = (_tmp5_ & GDK_CONTROL_MASK) != 0;
#line 1657 "contacts-window.c"
	} else {
#line 360 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp0_ = FALSE;
#line 1661 "contacts-window.c"
	}
#line 360 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp0_) {
#line 1665 "contacts-window.c"
		ContactsContactPane* _tmp6_ = NULL;
#line 363 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp6_ = self->priv->contact_pane;
#line 363 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_contact_pane_show_contact (_tmp6_, NULL, TRUE);
#line 364 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		gtk_widget_destroy ((GtkWidget*) self);
#line 1673 "contacts-window.c"
	} else {
		gboolean _tmp7_ = FALSE;
		gboolean _tmp8_ = FALSE;
		GdkEventKey* _tmp9_ = NULL;
		guint _tmp10_ = 0U;
#line 365 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp9_ = event;
#line 365 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp10_ = _tmp9_->keyval;
#line 365 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		if (_tmp10_ == ((guint) GDK_KEY_s)) {
#line 365 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp8_ = TRUE;
#line 1687 "contacts-window.c"
		} else {
			GdkEventKey* _tmp11_ = NULL;
			guint _tmp12_ = 0U;
#line 366 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp11_ = event;
#line 366 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp12_ = _tmp11_->keyval;
#line 366 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp8_ = _tmp12_ == ((guint) GDK_KEY_f);
#line 1697 "contacts-window.c"
		}
#line 365 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		if (_tmp8_) {
#line 1701 "contacts-window.c"
			GdkEventKey* _tmp13_ = NULL;
			GdkModifierType _tmp14_ = 0;
#line 367 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp13_ = event;
#line 367 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp14_ = _tmp13_->state;
#line 367 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp7_ = (_tmp14_ & GDK_CONTROL_MASK) != 0;
#line 1710 "contacts-window.c"
		} else {
#line 365 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp7_ = FALSE;
#line 1714 "contacts-window.c"
		}
#line 365 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		if (_tmp7_) {
#line 1718 "contacts-window.c"
			ContactsListPane* _tmp15_ = NULL;
			GtkSearchEntry* _tmp16_ = NULL;
#line 368 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp15_ = self->priv->list_pane;
#line 368 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp16_ = _tmp15_->filter_entry;
#line 368 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			contacts_utils_grab_entry_focus_no_select ((GtkEntry*) _tmp16_);
#line 1727 "contacts-window.c"
		} else {
			gboolean _tmp17_ = FALSE;
			gboolean _tmp18_ = FALSE;
			gboolean _tmp19_ = FALSE;
			gboolean _tmp20_ = FALSE;
			gboolean _tmp21_ = FALSE;
			gboolean _tmp22_ = FALSE;
			GdkEventKey* _tmp23_ = NULL;
			gint _tmp24_ = 0;
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp23_ = event;
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp24_ = _tmp23_->length;
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			if (_tmp24_ >= 1) {
#line 1743 "contacts-window.c"
				GdkEventKey* _tmp25_ = NULL;
				guint _tmp26_ = 0U;
				guint32 _tmp27_ = 0U;
#line 370 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp25_ = event;
#line 370 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp26_ = _tmp25_->keyval;
#line 370 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp27_ = gdk_keyval_to_unicode (_tmp26_);
#line 370 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp22_ = _tmp27_ != ((guint32) 0);
#line 1755 "contacts-window.c"
			} else {
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp22_ = FALSE;
#line 1759 "contacts-window.c"
			}
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			if (_tmp22_) {
#line 1763 "contacts-window.c"
				GdkEventKey* _tmp28_ = NULL;
				GdkModifierType _tmp29_ = 0;
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp28_ = event;
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp29_ = _tmp28_->state;
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp21_ = (_tmp29_ & GDK_CONTROL_MASK) == 0;
#line 1772 "contacts-window.c"
			} else {
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp21_ = FALSE;
#line 1776 "contacts-window.c"
			}
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			if (_tmp21_) {
#line 1780 "contacts-window.c"
				GdkEventKey* _tmp30_ = NULL;
				GdkModifierType _tmp31_ = 0;
#line 372 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp30_ = event;
#line 372 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp31_ = _tmp30_->state;
#line 372 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp20_ = (_tmp31_ & GDK_MOD1_MASK) == 0;
#line 1789 "contacts-window.c"
			} else {
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp20_ = FALSE;
#line 1793 "contacts-window.c"
			}
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			if (_tmp20_) {
#line 1797 "contacts-window.c"
				GdkEventKey* _tmp32_ = NULL;
				guint _tmp33_ = 0U;
#line 373 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp32_ = event;
#line 373 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp33_ = _tmp32_->keyval;
#line 373 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp19_ = _tmp33_ != ((guint) GDK_KEY_Escape);
#line 1806 "contacts-window.c"
			} else {
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp19_ = FALSE;
#line 1810 "contacts-window.c"
			}
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			if (_tmp19_) {
#line 1814 "contacts-window.c"
				GdkEventKey* _tmp34_ = NULL;
				guint _tmp35_ = 0U;
#line 374 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp34_ = event;
#line 374 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp35_ = _tmp34_->keyval;
#line 374 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp18_ = _tmp35_ != ((guint) GDK_KEY_Tab);
#line 1823 "contacts-window.c"
			} else {
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp18_ = FALSE;
#line 1827 "contacts-window.c"
			}
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			if (_tmp18_) {
#line 1831 "contacts-window.c"
				GdkEventKey* _tmp36_ = NULL;
				guint _tmp37_ = 0U;
#line 375 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp36_ = event;
#line 375 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp37_ = _tmp36_->keyval;
#line 375 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp17_ = _tmp37_ != ((guint) GDK_KEY_BackSpace);
#line 1840 "contacts-window.c"
			} else {
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp17_ = FALSE;
#line 1844 "contacts-window.c"
			}
#line 369 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			if (_tmp17_) {
#line 1848 "contacts-window.c"
				ContactsListPane* _tmp38_ = NULL;
				GtkSearchEntry* _tmp39_ = NULL;
				GdkEventKey* _tmp40_ = NULL;
#line 376 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp38_ = self->priv->list_pane;
#line 376 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp39_ = _tmp38_->filter_entry;
#line 376 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				contacts_utils_grab_entry_focus_no_select ((GtkEntry*) _tmp39_);
#line 377 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp40_ = event;
#line 377 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				gtk_window_propagate_key_event ((GtkWindow*) self, _tmp40_);
#line 1862 "contacts-window.c"
			}
		}
	}
#line 380 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	result = FALSE;
#line 380 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return result;
#line 1870 "contacts-window.c"
}


static gboolean _contacts_window_key_press_event_cb_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = contacts_window_key_press_event_cb ((ContactsWindow*) self, event);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return result;
#line 1879 "contacts-window.c"
}


static gboolean contacts_window_delete_event_cb (ContactsWindow* self, GdkEventAny* event) {
	gboolean result = FALSE;
	ContactsContactPane* _tmp0_ = NULL;
#line 384 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 384 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 386 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->contact_pane;
#line 386 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_contact_pane_show_contact (_tmp0_, NULL, TRUE);
#line 387 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	result = FALSE;
#line 387 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return result;
#line 1898 "contacts-window.c"
}


static gboolean _contacts_window_delete_event_cb_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = contacts_window_delete_event_cb ((ContactsWindow*) self, event);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return result;
#line 1907 "contacts-window.c"
}


static void contacts_window_list_pane_selection_changed_cb (ContactsWindow* self, ContactsContact* new_selection) {
	ContactsContact* _tmp0_ = NULL;
#line 390 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 391 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = new_selection;
#line 391 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_shown_contact (self, _tmp0_);
#line 1919 "contacts-window.c"
}


static Block43Data* block43_data_ref (Block43Data* _data43_) {
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_atomic_int_inc (&_data43_->_ref_count_);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return _data43_;
#line 1928 "contacts-window.c"
}


static void block43_data_unref (void * _userdata_) {
	Block43Data* _data43_;
	_data43_ = (Block43Data*) _userdata_;
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (g_atomic_int_dec_and_test (&_data43_->_ref_count_)) {
#line 1937 "contacts-window.c"
		ContactsWindow* self;
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		self = _data43_->self;
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data43_->notification);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data43_->operation);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (self);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_slice_free (Block43Data, _data43_);
#line 1949 "contacts-window.c"
	}
}


static void __lambda106_ (Block43Data* _data43_, GObject* obj, GAsyncResult* _result_) {
	ContactsWindow* self;
	GAsyncResult* _tmp0_ = NULL;
	ContactsLinkOperation2* _tmp1_ = NULL;
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data43_->self;
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (_result_ != NULL);
#line 401 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = _result_;
#line 401 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = contacts_link_contacts_list_finish (_tmp0_);
#line 401 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (_data43_->operation);
#line 401 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data43_->operation = _tmp1_;
#line 1970 "contacts-window.c"
}


static void ___lambda106__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda106_ (self, source_object, res);
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	block43_data_unref (self);
#line 1979 "contacts-window.c"
}


static void __lambda107_ (Block43Data* _data43_) {
	ContactsWindow* self;
#line 423 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data43_->self;
#line 425 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_link_operation2_undo (_data43_->operation, NULL, NULL);
#line 427 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gd_notification_dismiss (_data43_->notification);
#line 1991 "contacts-window.c"
}


static void ___lambda107__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 423 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda107_ (self);
#line 1998 "contacts-window.c"
}


static void contacts_window_list_pane_link_contacts_cb (ContactsWindow* self, GeeLinkedList* contact_list) {
	Block43Data* _data43_;
	GtkToggleButton* _tmp0_ = NULL;
	GeeLinkedList* _tmp1_ = NULL;
	GdNotification* _tmp2_ = NULL;
	GtkGrid* g = NULL;
	GtkGrid* _tmp3_ = NULL;
	gchar* msg = NULL;
	GeeLinkedList* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	const gchar* _tmp7_ = NULL;
	GeeLinkedList* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
	gchar* _tmp11_ = NULL;
	GtkButton* b = NULL;
	const gchar* _tmp12_ = NULL;
	GtkButton* _tmp13_ = NULL;
	GtkLabel* _tmp14_ = NULL;
	GtkLabel* _tmp15_ = NULL;
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (contact_list != NULL);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data43_ = g_slice_new0 (Block43Data);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data43_->_ref_count_ = 1;
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data43_->self = g_object_ref (self);
#line 396 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_shown_contact (self, NULL);
#line 397 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->select_button;
#line 397 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_toggle_button_set_active (_tmp0_, FALSE);
#line 399 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data43_->operation = NULL;
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = contact_list;
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_link_contacts_list (_tmp1_, ___lambda106__gasync_ready_callback, block43_data_ref (_data43_));
#line 404 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = (GdNotification*) gd_notification_new ();
#line 404 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp2_);
#line 404 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data43_->notification = _tmp2_;
#line 405 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_set (_data43_->notification, "timeout", 5, NULL);
#line 407 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = (GtkGrid*) gtk_grid_new ();
#line 407 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp3_);
#line 407 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g = _tmp3_;
#line 408 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_grid_set_column_spacing (g, (guint) 8);
#line 409 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) _data43_->notification, (GtkWidget*) g);
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = contact_list;
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp4_);
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = _tmp5_;
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = ngettext ("%d contacts linked", "%d contacts linked", (gulong) _tmp6_);
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp8_ = contact_list;
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp9_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp8_);
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp10_ = _tmp9_;
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp11_ = g_strdup_printf (_tmp7_, _tmp10_);
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	msg = _tmp11_;
#line 415 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp12_ = _ ("_Undo");
#line 415 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp13_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp12_);
#line 415 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp13_);
#line 415 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	b = _tmp13_;
#line 416 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp14_ = (GtkLabel*) gtk_label_new (msg);
#line 416 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp14_);
#line 416 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp15_ = _tmp14_;
#line 416 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) g, (GtkWidget*) _tmp15_);
#line 416 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (_tmp15_);
#line 417 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) g, (GtkWidget*) b);
#line 419 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_show_all ((GtkWidget*) _data43_->notification);
#line 420 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_add_notification (self, (GtkWidget*) _data43_->notification);
#line 423 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_data (b, "clicked", (GCallback) ___lambda107__gtk_button_clicked, block43_data_ref (_data43_), (GClosureNotify) block43_data_unref, 0);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (b);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_free0 (msg);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (g);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	block43_data_unref (_data43_);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data43_ = NULL;
#line 2117 "contacts-window.c"
}


static Block44Data* block44_data_ref (Block44Data* _data44_) {
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_atomic_int_inc (&_data44_->_ref_count_);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return _data44_;
#line 2126 "contacts-window.c"
}


static void block44_data_unref (void * _userdata_) {
	Block44Data* _data44_;
	_data44_ = (Block44Data*) _userdata_;
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (g_atomic_int_dec_and_test (&_data44_->_ref_count_)) {
#line 2135 "contacts-window.c"
		ContactsWindow* self;
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		self = _data44_->self;
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data44_->notification);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data44_->contact_list);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (self);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_slice_free (Block44Data, _data44_);
#line 2147 "contacts-window.c"
	}
}


static void __lambda108_ (Block44Data* _data44_) {
	ContactsWindow* self;
#line 456 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data44_->self;
#line 457 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_data44_->really_delete) {
#line 2158 "contacts-window.c"
		{
			GeeLinkedList* _c_list = NULL;
			GeeLinkedList* _tmp0_ = NULL;
			GeeLinkedList* _tmp1_ = NULL;
			gint _c_size = 0;
			GeeLinkedList* _tmp2_ = NULL;
			gint _tmp3_ = 0;
			gint _tmp4_ = 0;
			gint _c_index = 0;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp0_ = _data44_->contact_list;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp1_ = _g_object_ref0 (_tmp0_);
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_c_list = _tmp1_;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp2_ = _c_list;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp3_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp2_);
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp4_ = _tmp3_;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_c_size = _tmp4_;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_c_index = -1;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			while (TRUE) {
#line 2186 "contacts-window.c"
				gint _tmp5_ = 0;
				gint _tmp6_ = 0;
				gint _tmp7_ = 0;
				ContactsContact* c = NULL;
				GeeLinkedList* _tmp8_ = NULL;
				gint _tmp9_ = 0;
				gpointer _tmp10_ = NULL;
				ContactsContact* _tmp11_ = NULL;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp5_ = _c_index;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_c_index = _tmp5_ + 1;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp6_ = _c_index;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp7_ = _c_size;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				if (!(_tmp6_ < _tmp7_)) {
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
					break;
#line 2207 "contacts-window.c"
				}
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp8_ = _c_list;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp9_ = _c_index;
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp10_ = gee_abstract_list_get ((GeeAbstractList*) _tmp8_, _tmp9_);
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				c = (ContactsContact*) _tmp10_;
#line 459 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_tmp11_ = c;
#line 459 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				contacts_contact_remove_personas (_tmp11_, NULL, NULL);
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				_g_object_unref0 (c);
#line 2223 "contacts-window.c"
			}
#line 458 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_g_object_unref0 (_c_list);
#line 2227 "contacts-window.c"
		}
	}
}


static void ___lambda108__gd_notification_dismissed (GdNotification* _sender, gpointer self) {
#line 456 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda108_ (self);
#line 2236 "contacts-window.c"
}


static void __lambda109_ (Block44Data* _data44_) {
	ContactsWindow* self;
	GeeLinkedList* _tmp12_ = NULL;
	gpointer _tmp13_ = NULL;
	ContactsContact* _tmp14_ = NULL;
#line 463 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data44_->self;
#line 464 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data44_->really_delete = FALSE;
#line 465 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gd_notification_dismiss (_data44_->notification);
#line 2251 "contacts-window.c"
	{
		GeeLinkedList* _c_list = NULL;
		GeeLinkedList* _tmp0_ = NULL;
		GeeLinkedList* _tmp1_ = NULL;
		gint _c_size = 0;
		GeeLinkedList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _c_index = 0;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp0_ = _data44_->contact_list;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_c_list = _tmp1_;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp2_ = _c_list;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp3_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp2_);
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp4_ = _tmp3_;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_c_size = _tmp4_;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_c_index = -1;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		while (TRUE) {
#line 2279 "contacts-window.c"
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			ContactsContact* c = NULL;
			GeeLinkedList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			ContactsContact* _tmp11_ = NULL;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp5_ = _c_index;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_c_index = _tmp5_ + 1;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp6_ = _c_index;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp7_ = _c_size;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			if (!(_tmp6_ < _tmp7_)) {
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
				break;
#line 2300 "contacts-window.c"
			}
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp8_ = _c_list;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp9_ = _c_index;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp10_ = gee_abstract_list_get ((GeeAbstractList*) _tmp8_, _tmp9_);
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			c = (ContactsContact*) _tmp10_;
#line 467 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_tmp11_ = c;
#line 467 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			contacts_contact_show (_tmp11_);
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
			_g_object_unref0 (c);
#line 2316 "contacts-window.c"
		}
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_c_list);
#line 2320 "contacts-window.c"
	}
#line 469 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp12_ = _data44_->contact_list;
#line 469 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp13_ = gee_linked_list_last (_tmp12_);
#line 469 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp14_ = (ContactsContact*) _tmp13_;
#line 469 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_shown_contact (self, _tmp14_);
#line 469 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (_tmp14_);
#line 2332 "contacts-window.c"
}


static void ___lambda109__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 463 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda109_ (self);
#line 2339 "contacts-window.c"
}


static void contacts_window_list_pane_delete_contacts_cb (ContactsWindow* self, GeeLinkedList* contact_list) {
	Block44Data* _data44_;
	GeeLinkedList* _tmp0_ = NULL;
	GeeLinkedList* _tmp1_ = NULL;
	GtkToggleButton* _tmp2_ = NULL;
	GdNotification* _tmp3_ = NULL;
	GtkGrid* g = NULL;
	GtkGrid* _tmp4_ = NULL;
	gchar* msg = NULL;
	GeeLinkedList* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	const gchar* _tmp8_ = NULL;
	GeeLinkedList* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
	gchar* _tmp12_ = NULL;
	GtkButton* b = NULL;
	const gchar* _tmp13_ = NULL;
	GtkButton* _tmp14_ = NULL;
	GtkLabel* _tmp15_ = NULL;
	GtkLabel* _tmp16_ = NULL;
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (contact_list != NULL);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data44_ = g_slice_new0 (Block44Data);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data44_->_ref_count_ = 1;
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data44_->self = g_object_ref (self);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = contact_list;
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (_data44_->contact_list);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data44_->contact_list = _tmp1_;
#line 433 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_shown_contact (self, NULL);
#line 434 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = self->priv->select_button;
#line 434 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_toggle_button_set_active (_tmp2_, FALSE);
#line 436 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = (GdNotification*) gd_notification_new ();
#line 436 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp3_);
#line 436 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data44_->notification = _tmp3_;
#line 437 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_set (_data44_->notification, "timeout", 5, NULL);
#line 439 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = (GtkGrid*) gtk_grid_new ();
#line 439 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp4_);
#line 439 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g = _tmp4_;
#line 440 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_grid_set_column_spacing (g, (guint) 8);
#line 441 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) _data44_->notification, (GtkWidget*) g);
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = _data44_->contact_list;
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp5_);
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = _tmp6_;
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp8_ = ngettext ("%d contact deleted", "%d contacts deleted", (gulong) _tmp7_);
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp9_ = _data44_->contact_list;
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp10_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp9_);
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp11_ = _tmp10_;
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp12_ = g_strdup_printf (_tmp8_, _tmp11_);
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	msg = _tmp12_;
#line 447 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp13_ = _ ("_Undo");
#line 447 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp14_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp13_);
#line 447 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp14_);
#line 447 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	b = _tmp14_;
#line 448 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp15_ = (GtkLabel*) gtk_label_new (msg);
#line 448 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp15_);
#line 448 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp16_ = _tmp15_;
#line 448 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) g, (GtkWidget*) _tmp16_);
#line 448 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (_tmp16_);
#line 449 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) g, (GtkWidget*) b);
#line 451 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_show_all ((GtkWidget*) _data44_->notification);
#line 452 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_add_notification (self, (GtkWidget*) _data44_->notification);
#line 455 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data44_->really_delete = TRUE;
#line 456 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_data (_data44_->notification, "dismissed", (GCallback) ___lambda108__gd_notification_dismissed, block44_data_ref (_data44_), (GClosureNotify) block44_data_unref, 0);
#line 463 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_data (b, "clicked", (GCallback) ___lambda109__gtk_button_clicked, block44_data_ref (_data44_), (GClosureNotify) block44_data_unref, 0);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (b);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_free0 (msg);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (g);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	block44_data_unref (_data44_);
#line 431 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data44_ = NULL;
#line 2465 "contacts-window.c"
}


static Block45Data* block45_data_ref (Block45Data* _data45_) {
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_atomic_int_inc (&_data45_->_ref_count_);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return _data45_;
#line 2474 "contacts-window.c"
}


static void block45_data_unref (void * _userdata_) {
	Block45Data* _data45_;
	_data45_ = (Block45Data*) _userdata_;
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (g_atomic_int_dec_and_test (&_data45_->_ref_count_)) {
#line 2483 "contacts-window.c"
		ContactsWindow* self;
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		self = _data45_->self;
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data45_->notification);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data45_->contact);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (self);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_slice_free (Block45Data, _data45_);
#line 2495 "contacts-window.c"
	}
}


static void ___lambda112_ (Block45Data* _data45_) {
	ContactsWindow* self;
	ContactsContact* _tmp0_ = NULL;
#line 497 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data45_->self;
#line 498 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = _data45_->contact;
#line 498 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_contact_show (_tmp0_);
#line 2509 "contacts-window.c"
}


static void ____lambda112__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 497 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	___lambda112_ (self);
#line 497 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	block45_data_unref (self);
#line 2518 "contacts-window.c"
}


static void __lambda111_ (Block45Data* _data45_) {
	ContactsWindow* self;
#line 495 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data45_->self;
#line 496 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_data45_->really_delete) {
#line 2528 "contacts-window.c"
		ContactsContact* _tmp0_ = NULL;
#line 497 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp0_ = _data45_->contact;
#line 497 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_contact_remove_personas (_tmp0_, ____lambda112__gasync_ready_callback, block45_data_ref (_data45_));
#line 2534 "contacts-window.c"
	}
}


static void ___lambda111__gd_notification_dismissed (GdNotification* _sender, gpointer self) {
#line 495 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda111_ (self);
#line 2542 "contacts-window.c"
}


static void __lambda113_ (Block45Data* _data45_) {
	ContactsWindow* self;
	ContactsContact* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
#line 501 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data45_->self;
#line 502 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data45_->really_delete = FALSE;
#line 503 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gd_notification_dismiss (_data45_->notification);
#line 504 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = _data45_->contact;
#line 504 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_contact_show (_tmp0_);
#line 505 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _data45_->contact;
#line 505 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_shown_contact (self, _tmp1_);
#line 2564 "contacts-window.c"
}


static void ___lambda113__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 501 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda113_ (self);
#line 2571 "contacts-window.c"
}


static void contacts_window_contact_pane_delete_contact_cb (ContactsWindow* self, ContactsContact* contact) {
	Block45Data* _data45_;
	ContactsContact* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
	GtkToggleButton* _tmp2_ = NULL;
	GdNotification* _tmp3_ = NULL;
	GtkGrid* g = NULL;
	GtkGrid* _tmp4_ = NULL;
	GtkLabel* label = NULL;
	const gchar* _tmp5_ = NULL;
	ContactsContact* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	GtkLabel* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	GtkButton* b = NULL;
	const gchar* _tmp13_ = NULL;
	GtkButton* _tmp14_ = NULL;
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (contact != NULL);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data45_ = g_slice_new0 (Block45Data);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data45_->_ref_count_ = 1;
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data45_->self = g_object_ref (self);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = contact;
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (_data45_->contact);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data45_->contact = _tmp1_;
#line 476 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_set_shown_contact (self, NULL);
#line 477 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = self->priv->select_button;
#line 477 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_toggle_button_set_active (_tmp2_, FALSE);
#line 479 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = (GdNotification*) gd_notification_new ();
#line 479 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp3_);
#line 479 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data45_->notification = _tmp3_;
#line 480 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_set (_data45_->notification, "timeout", 5, NULL);
#line 482 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = (GtkGrid*) gtk_grid_new ();
#line 482 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp4_);
#line 482 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g = _tmp4_;
#line 483 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_grid_set_column_spacing (g, (guint) 8);
#line 484 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) _data45_->notification, (GtkWidget*) g);
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = _ ("Contact deleted: \"%s\"");
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = _data45_->contact;
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = contacts_contact_get_display_name (_tmp6_);
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp8_ = _tmp7_;
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp9_ = g_strdup_printf (_tmp5_, _tmp8_);
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp10_ = _tmp9_;
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp11_ = (GtkLabel*) gtk_label_new (_tmp10_);
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp11_);
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp12_ = _tmp11_;
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_free0 (_tmp10_);
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	label = _tmp12_;
#line 487 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_label_set_max_width_chars (label, 45);
#line 488 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
#line 489 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp13_ = _ ("_Undo");
#line 489 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp14_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp13_);
#line 489 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp14_);
#line 489 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	b = _tmp14_;
#line 490 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) g, (GtkWidget*) label);
#line 491 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) g, (GtkWidget*) b);
#line 493 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data45_->really_delete = TRUE;
#line 494 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_show_all ((GtkWidget*) _data45_->notification);
#line 495 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_data (_data45_->notification, "dismissed", (GCallback) ___lambda111__gd_notification_dismissed, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 501 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_data (b, "clicked", (GCallback) ___lambda113__gtk_button_clicked, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 507 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_add_notification (self, (GtkWidget*) _data45_->notification);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (b);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (label);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (g);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	block45_data_unref (_data45_);
#line 474 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data45_ = NULL;
#line 2695 "contacts-window.c"
}


static void _contacts_window_contact_pane_delete_contact_cb_contacts_contact_pane_will_delete (ContactsContactPane* _sender, ContactsContact* contact, gpointer self) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_contact_pane_delete_contact_cb ((ContactsWindow*) self, contact);
#line 2702 "contacts-window.c"
}


static Block46Data* block46_data_ref (Block46Data* _data46_) {
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_atomic_int_inc (&_data46_->_ref_count_);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return _data46_;
#line 2711 "contacts-window.c"
}


static void block46_data_unref (void * _userdata_) {
	Block46Data* _data46_;
	_data46_ = (Block46Data*) _userdata_;
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (g_atomic_int_dec_and_test (&_data46_->_ref_count_)) {
#line 2720 "contacts-window.c"
		ContactsWindow* self;
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		self = _data46_->self;
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data46_->notification);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (_data46_->operation);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_object_unref0 (self);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_slice_free (Block46Data, _data46_);
#line 2732 "contacts-window.c"
	}
}


static void __lambda114_ (Block46Data* _data46_) {
	ContactsWindow* self;
	GdNotification* _tmp0_ = NULL;
	ContactsLinkOperation* _tmp1_ = NULL;
#line 530 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = _data46_->self;
#line 531 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = _data46_->notification;
#line 531 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gd_notification_dismiss (_tmp0_);
#line 532 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _data46_->operation;
#line 532 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_link_operation_undo (_tmp1_, NULL, NULL);
#line 2751 "contacts-window.c"
}


static void ___lambda114__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 530 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	__lambda114_ (self);
#line 2758 "contacts-window.c"
}


static void contacts_window_contact_pane_contacts_linked_cb (ContactsWindow* self, const gchar* main_contact, const gchar* linked_contact, ContactsLinkOperation* operation) {
	Block46Data* _data46_;
	ContactsLinkOperation* _tmp0_ = NULL;
	ContactsLinkOperation* _tmp1_ = NULL;
	GdNotification* _tmp2_ = NULL;
	GdNotification* _tmp3_ = NULL;
	GtkGrid* g = NULL;
	GtkGrid* _tmp4_ = NULL;
	GtkGrid* _tmp5_ = NULL;
	GdNotification* _tmp6_ = NULL;
	GtkGrid* _tmp7_ = NULL;
	gchar* msg = NULL;
	const gchar* _tmp8_ = NULL;
	GtkButton* b = NULL;
	const gchar* _tmp16_ = NULL;
	GtkButton* _tmp17_ = NULL;
	GtkGrid* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	GtkLabel* _tmp20_ = NULL;
	GtkLabel* _tmp21_ = NULL;
	GtkGrid* _tmp22_ = NULL;
	GdNotification* _tmp23_ = NULL;
	GdNotification* _tmp24_ = NULL;
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (linked_contact != NULL);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (operation != NULL);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data46_ = g_slice_new0 (Block46Data);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data46_->_ref_count_ = 1;
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data46_->self = g_object_ref (self);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = operation;
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (_data46_->operation);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data46_->operation = _tmp1_;
#line 512 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp2_ = (GdNotification*) gd_notification_new ();
#line 512 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp2_);
#line 512 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data46_->notification = _tmp2_;
#line 513 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp3_ = _data46_->notification;
#line 513 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_set (_tmp3_, "timeout", 5, NULL);
#line 515 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp4_ = (GtkGrid*) gtk_grid_new ();
#line 515 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp4_);
#line 515 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g = _tmp4_;
#line 516 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp5_ = g;
#line 516 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_grid_set_column_spacing (_tmp5_, (guint) 8);
#line 517 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp6_ = _data46_->notification;
#line 517 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp7_ = g;
#line 517 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) _tmp6_, (GtkWidget*) _tmp7_);
#line 520 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp8_ = main_contact;
#line 520 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	if (_tmp8_ != NULL) {
#line 2835 "contacts-window.c"
		const gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
#line 521 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp9_ = _ ("%s linked to %s");
#line 521 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp10_ = main_contact;
#line 521 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp11_ = linked_contact;
#line 521 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp12_ = g_strdup_printf (_tmp9_, _tmp10_, _tmp11_);
#line 521 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_free0 (msg);
#line 521 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		msg = _tmp12_;
#line 2852 "contacts-window.c"
	} else {
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
#line 523 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp13_ = _ ("%s linked to the contact");
#line 523 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp14_ = linked_contact;
#line 523 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_tmp15_ = g_strdup_printf (_tmp13_, _tmp14_);
#line 523 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		_g_free0 (msg);
#line 523 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		msg = _tmp15_;
#line 2867 "contacts-window.c"
	}
#line 525 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp16_ = _ ("_Undo");
#line 525 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp17_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp16_);
#line 525 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp17_);
#line 525 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	b = _tmp17_;
#line 526 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp18_ = g;
#line 526 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp19_ = msg;
#line 526 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp20_ = (GtkLabel*) gtk_label_new (_tmp19_);
#line 526 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_ref_sink (_tmp20_);
#line 526 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp21_ = _tmp20_;
#line 526 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) _tmp18_, (GtkWidget*) _tmp21_);
#line 526 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (_tmp21_);
#line 527 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp22_ = g;
#line 527 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_container_add ((GtkContainer*) _tmp22_, (GtkWidget*) b);
#line 529 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp23_ = _data46_->notification;
#line 529 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp23_);
#line 530 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_signal_connect_data (b, "clicked", (GCallback) ___lambda114__gtk_button_clicked, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
#line 534 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp24_ = _data46_->notification;
#line 534 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_add_notification (self, (GtkWidget*) _tmp24_);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (b);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_free0 (msg);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (g);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	block46_data_unref (_data46_);
#line 511 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_data46_ = NULL;
#line 2915 "contacts-window.c"
}


static void _contacts_window_contact_pane_contacts_linked_cb_contacts_contact_pane_contacts_linked (ContactsContactPane* _sender, const gchar* main_contact, const gchar* linked_contact, ContactsLinkOperation* operation, gpointer self) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_contact_pane_contacts_linked_cb ((ContactsWindow*) self, main_contact, linked_contact, operation);
#line 2922 "contacts-window.c"
}


static const gchar* contacts_window_get_left_title (ContactsWindow* self) {
	const gchar* result;
	GtkHeaderBar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->left_toolbar;
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = gtk_header_bar_get_title (_tmp0_);
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	result = _tmp1_;
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return result;
#line 2940 "contacts-window.c"
}


static void contacts_window_set_left_title (ContactsWindow* self, const gchar* value) {
	GtkHeaderBar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->left_toolbar;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = value;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_header_bar_set_title (_tmp0_, _tmp1_);
#line 2955 "contacts-window.c"
}


static const gchar* contacts_window_get_right_title (ContactsWindow* self) {
	const gchar* result;
	GtkHeaderBar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 77 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 78 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->right_toolbar;
#line 78 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = gtk_header_bar_get_title (_tmp0_);
#line 78 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	result = _tmp1_;
#line 78 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return result;
#line 2973 "contacts-window.c"
}


static void contacts_window_set_right_title (ContactsWindow* self, const gchar* value) {
	GtkHeaderBar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->right_toolbar;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = value;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_header_bar_set_title (_tmp0_, _tmp1_);
#line 2988 "contacts-window.c"
}


ContactsStore* contacts_window_get_store (ContactsWindow* self) {
	ContactsStore* result;
	ContactsStore* _tmp0_ = NULL;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->_store;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	result = _tmp0_;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return result;
#line 3003 "contacts-window.c"
}


void contacts_window_set_store (ContactsWindow* self, ContactsStore* value) {
	ContactsStore* _tmp0_ = NULL;
	ContactsStore* _tmp1_ = NULL;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = value;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->_store);
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self->priv->_store = _tmp1_;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_notify ((GObject *) self, "store");
#line 3022 "contacts-window.c"
}


gboolean contacts_window_get_selection_mode (ContactsWindow* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->_selection_mode;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	result = _tmp0_;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return result;
#line 3037 "contacts-window.c"
}


void contacts_window_set_selection_mode (ContactsWindow* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = value;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self->priv->_selection_mode = _tmp0_;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_notify ((GObject *) self, "selection-mode");
#line 3051 "contacts-window.c"
}


gboolean contacts_window_get_edit_mode (ContactsWindow* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = self->priv->_edit_mode;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	result = _tmp0_;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	return result;
#line 3066 "contacts-window.c"
}


void contacts_window_set_edit_mode (ContactsWindow* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_return_if_fail (self != NULL);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_tmp0_ = value;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self->priv->_edit_mode = _tmp0_;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_notify ((GObject *) self, "edit-mode");
#line 3080 "contacts-window.c"
}


static void contacts_window_class_init (ContactsWindowClass * klass) {
	gint ContactsWindow_private_offset;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	contacts_window_parent_class = g_type_class_peek_parent (klass);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_type_class_add_private (klass, sizeof (ContactsWindowPrivate));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_contacts_window_get_property;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_contacts_window_set_property;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	G_OBJECT_CLASS (klass)->finalize = contacts_window_finalize;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONTACTS_WINDOW_STORE, g_param_spec_object ("store", "store", "store", CONTACTS_TYPE_STORE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONTACTS_WINDOW_SELECTION_MODE, g_param_spec_boolean ("selection-mode", "selection-mode", "selection-mode", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONTACTS_WINDOW_EDIT_MODE, g_param_spec_boolean ("edit-mode", "edit-mode", "edit-mode", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	ContactsWindow_private_offset = g_type_class_get_instance_private_offset (klass);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/contacts/ui/contacts-window.ui");
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "content_grid", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, content_grid));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "loading_box", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, loading_box));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "left_pane_size_group", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, left_pane_size_group));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "left_toolbar", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, left_toolbar));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "right_toolbar", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, right_toolbar));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "overlay", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, overlay));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "contact_pane", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, contact_pane));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "add_button", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, add_button));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "select_button", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, select_button));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "edit_button", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, edit_button));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "cancel_button", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, cancel_button));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "done_button", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, done_button));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "view_switcher", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, view_switcher));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "content_header_bar", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, content_header_bar));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "setup_header_bar", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, setup_header_bar));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "setup_done_button", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, setup_done_button));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "setup_cancel_button", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, setup_cancel_button));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "setup_accounts_list", FALSE, ContactsWindow_private_offset + G_STRUCT_OFFSET (ContactsWindowPrivate, setup_accounts_list));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "new_contact", G_CALLBACK(_contacts_window_new_contact_gtk_button_clicked));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "key_press_event_cb", G_CALLBACK(_contacts_window_key_press_event_cb_gtk_widget_key_press_event));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "delete_event_cb", G_CALLBACK(_contacts_window_delete_event_cb_gtk_widget_delete_event));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "contact_pane_delete_contact_cb", G_CALLBACK(_contacts_window_contact_pane_delete_contact_cb_contacts_contact_pane_will_delete));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "contact_pane_contacts_linked_cb", G_CALLBACK(_contacts_window_contact_pane_contacts_linked_cb_contacts_contact_pane_contacts_linked));
#line 3152 "contacts-window.c"
}


static void contacts_window_instance_init (ContactsWindow * self) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self->priv = CONTACTS_WINDOW_GET_PRIVATE (self);
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self->priv->new_contact_mode = FALSE;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_type_ensure (CONTACTS_TYPE_ACCOUNTS_LIST);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	g_type_ensure (CONTACTS_TYPE_CONTACT_PANE);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 3167 "contacts-window.c"
}


static void contacts_window_finalize (GObject* obj) {
	ContactsWindow * self;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CONTACTS_TYPE_WINDOW, ContactsWindow);
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->content_grid);
#line 28 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->loading_box);
#line 30 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->left_pane_size_group);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->left_toolbar);
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->right_toolbar);
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->overlay);
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->contact_pane);
#line 40 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->add_button);
#line 42 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->select_button);
#line 44 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->edit_button);
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->done_button);
#line 51 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->view_switcher);
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->content_header_bar);
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->setup_header_bar);
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->setup_done_button);
#line 61 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->setup_cancel_button);
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->setup_accounts_list);
#line 65 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->list_pane);
#line 87 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	_g_object_unref0 (self->priv->_store);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	G_OBJECT_CLASS (contacts_window_parent_class)->finalize (obj);
#line 3217 "contacts-window.c"
}


GType contacts_window_get_type (void) {
	static volatile gsize contacts_window_type_id__volatile = 0;
	if (g_once_init_enter (&contacts_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ContactsWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) contacts_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ContactsWindow), 0, (GInstanceInitFunc) contacts_window_instance_init, NULL };
		GType contacts_window_type_id;
		contacts_window_type_id = g_type_register_static (gtk_application_window_get_type (), "ContactsWindow", &g_define_type_info, 0);
		g_once_init_leave (&contacts_window_type_id__volatile, contacts_window_type_id);
	}
	return contacts_window_type_id__volatile;
}


static void _vala_contacts_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ContactsWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CONTACTS_TYPE_WINDOW, ContactsWindow);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	switch (property_id) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		case CONTACTS_WINDOW_STORE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_value_set_object (value, contacts_window_get_store (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		case CONTACTS_WINDOW_SELECTION_MODE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_value_set_boolean (value, contacts_window_get_selection_mode (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		case CONTACTS_WINDOW_EDIT_MODE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		g_value_set_boolean (value, contacts_window_get_edit_mode (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		break;
#line 3256 "contacts-window.c"
		default:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		break;
#line 3262 "contacts-window.c"
	}
}


static void _vala_contacts_window_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ContactsWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CONTACTS_TYPE_WINDOW, ContactsWindow);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
	switch (property_id) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		case CONTACTS_WINDOW_STORE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_store (self, g_value_get_object (value));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		case CONTACTS_WINDOW_SELECTION_MODE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_selection_mode (self, g_value_get_boolean (value));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		case CONTACTS_WINDOW_EDIT_MODE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		contacts_window_set_edit_mode (self, g_value_get_boolean (value));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		break;
#line 3290 "contacts-window.c"
		default:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-window.vala"
		break;
#line 3296 "contacts-window.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



